@@ -69,7 +69,7 @@ class ExampleDatasetApi(Resource):
         n_categories = max(1, n_categories)
 
         categories = None
-        if "20newsgroups" in name:
+        if "20_newsgroups_" in name:
             if n_categories == 3:
                 categories = ['comp.graphics', 'rec.sport.baseball',
                               'sci.space']
@@ -172,10 +172,12 @@ class FeaturesApiElement(Resource):
           - `data_dir`: [optional] relative path to the directory with the input files. Either `data_dir` or `dataset_definition` must be provided.
           - `dataset_definition`: [optional] a list of dictionaries `[{'file_path': <str>, 'content': <str>, 'document_id': <int>, 'rendition_id': <int>}, ...]` where `document_id` and `rendition_id` are optional, while either `file_path` or `content` field must be provided. 
           - `vectorize`: [optional] this option can be used to ingest the dataset_definition in batches (optionally with document content), then make one final call to vectorize all sent documents (bool, default: True)
+          - `document_id_generator`: [optional] if the `document_id` is not provided, this specifies how it is generated. If `indexed_file_path` the `document_id` is given by the index of the sorted `file_path`, otherwise if `infer_file_path` the `document_id` is inferred from the `file_path` strings, removing all non digit characters. In this second case, the `file_path` must contain a unique numeric ID (default: `indexed_file_path`)
          """))
     @use_args({"data_dir":  wfields.Str(),
                "dataset_definition": wfields.Nested(_DatasetDefinition, many=True),
-               "vectorize": wfields.Bool(missing=True)})
+               "vectorize": wfields.Bool(missing=True),
+               "document_id_generator": wfields.Str(missing="indexed_file_path")})
     @marshal_with(IDSchema())
     def post(self, dsid, **args):
         fe = FeatureVectorizer(self._cache_dir, dsid=dsid)
@@ -437,6 +439,8 @@ class ModelsApiPredict(Resource):
     @marshal_with(CategorizationPredictSchema())
     def get(self, mid, **args):
 
+        valid_sort = ['score']
+
         sort_by = args.pop('sort_by')
         sort_ascending = args.pop('sort_order') == 'ascending'
         max_result_categories = args.pop('max_result_categories')
@@ -451,13 +455,17 @@ class ModelsApiPredict(Resource):
         y_res, nn_res = cat.predict(**args)
         train_indices = cat._pars['index']
 
-        labels = cat.le.classes_
+        labels = list(cat.le.classes_)
         Y_pred = y_res
 
         if max_result_categories <= 0:
-            raise ValueError(('the max_result_categories={} '
-                              'must be strictly positive')
-                             .format(max_result_categories))
+            raise WrongParameter(('the max_result_categories={} '
+                                  'must be strictly positive')
+                                 .format(max_result_categories))
+        if sort_by not in valid_sort + labels:
+            raise WrongParameter(("sort_by={} not value. Must be "
+                                  "one of {}")
+                                 .format(sort_by, valid_sort + labels))
 
         id_mapping = cat.fe.db_.data
         # have to cast to object as otherwise
@@ -494,14 +502,13 @@ class ModelsApiPredict(Resource):
             Y_pred = Y_pred.loc[_mask, :]
 
         # sort output
+        if sort_by in labels:
+            Y_pred = Y_pred.sort_values(sort_by, ascending=sort_ascending)
+
         Y_pred_max = Y_pred[labels].max(axis=1)
-        if sort_by:
-            valid_sort = ['score']
+        if sort_by in valid_sort:
             if sort_by == 'score':
                 Y_pred_max = Y_pred_max.sort_values(ascending=sort_ascending)
-            else:
-                raise ValueError('sort_by={} not in {}'
-                                 .format(sort_by, valid_sort))
 
         # filter out low scores
         if min_score is not None:
